@@ -314,6 +314,7 @@ fn define_ar_impl(
                 pub table_name_as: Option<String>,
                 pub filters: Vec<Filter>,
                 pub preload: bool,
+                pub outer_join: bool,
                 pub orders: Vec<OrderItem>,
                 pub limit: Option<usize>,
                 pub offset: Option<usize>,
@@ -374,6 +375,13 @@ fn define_ar_impl(
                     }
                 }
 
+                pub fn outer_join(&self) -> Self {
+                    Self {
+                        outer_join: true,
+                        ..self.clone()
+                    }
+                }
+
                 pub async fn count<'a>(&self, conn: &arysn::Connection<'a>) -> arysn::Result<i64> {
                     let (sql, params) = BuilderTrait::count(self);
                     let row = conn.query_one(sql.as_str(), &params).await?;
